@@ -7,7 +7,7 @@ use Const::Fast;
 use URI;
 use URI::Escape;
 
-our $VERSION = '0.002001';
+our $VERSION = '0.002002';
 
 const our %INPUT_KEYS => (
     'codigo_empresa'    => 'nCdEmpresa',
@@ -140,10 +140,6 @@ __END__
 WWW::Correios::PrecoPrazo - Serviço de cálculo de preços e prazos de entrega
 de encomendas (Brazilian Postal Object Tracking Service)
 
-=head1 VERSION
-
-0.2.1
-
 =head1 DESCRIPTION
 
 This module provides a way to query the Brazilian Postal Office (Correios) via
@@ -383,7 +379,7 @@ Blabos de Blebe  C<< <blabos@cpan.org> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2011, Estante Virtual. All rights reserved.
+Copyright (c) 2011-2013, Estante Virtual. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
